@@ -3,7 +3,7 @@
 @author:XuMing(xuming624@qq.com)
 @description: Download file.
 """
-
+import requests
 import hashlib
 import os
 import shutil
@@ -13,7 +13,7 @@ import time
 import typing
 import zipfile
 from pathlib import Path
-
+from tqdm.autonotebook import tqdm
 import numpy as np
 import six
 from six.moves.urllib.error import HTTPError
@@ -349,3 +349,30 @@ def hash_file(fpath, algorithm='sha256', chunk_size=65535):
             hasher.update(chunk)
 
     return hasher.hexdigest()
+
+
+def http_get(url, path):
+    """
+    Downloads a URL to a given path on disc
+    """
+    if os.path.dirname(path) != '':
+        os.makedirs(os.path.dirname(path), exist_ok=True)
+
+    req = requests.get(url, stream=True)
+    if req.status_code != 200:
+        print("Exception when trying to download {}. Response {}".format(url, req.status_code), file=sys.stderr)
+        req.raise_for_status()
+        return
+
+    download_filepath = path + "_part"
+    with open(download_filepath, "wb") as file_binary:
+        content_length = req.headers.get('Content-Length')
+        total = int(content_length) if content_length is not None else None
+        progress = tqdm(unit="B", total=total, unit_scale=True)
+        for chunk in req.iter_content(chunk_size=1024):
+            if chunk:  # filter out keep-alive new chunks
+                progress.update(len(chunk))
+                file_binary.write(chunk)
+
+    os.rename(download_filepath, path)
+    progress.close()
